@@ -1,7 +1,7 @@
 package File::Slurper::Temp;
 
 our $DATE = '2017-01-16'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use warnings;
@@ -42,7 +42,15 @@ File::Slurper::Temp - File::Slurper + File::Temp
 
 =head1 VERSION
 
-This document describes version 0.001 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2017-01-16.
+This document describes version 0.002 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2017-01-16.
+
+=head1 SYNOPSIS
+
+Use like you would use L<File::Slurper>'s C<write_text> or C<write_binary>:
+
+ use File::Slurper::Temp qw(write_text write_binary);
+ write_text("/tmp/foo.txt", "some text");
+ write_binary("/tmp/bar", $somedata);
 
 =head1 DESCRIPTION
 
@@ -53,8 +61,6 @@ by L<File::Temp>'s C<tempfile>, then rename the temporary file to the originally
 specified name. If the filename is originally a symlink, it will be replaced
 with a regular file. This can avoid symlink attack.
 
-the L<File::RsyBak> distribution because it has fewer dependencies.
-
 =head1 FUNCTIONS
 
 =head2 write_text
